#
# spec file for package python-iminuit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%else
%bcond_without test
%define psuffix -%{flavor}
%if "%{flavor}" == "test-numba"
%bcond_without numba
%else
%bcond_with numba
%endif
%endif

%{?sle15_python_module_pythons}
Name:           python-iminuit%{psuffix}
Version:        2.30.1
Release:        1.3
Summary:        Python bindings for MINUIT2
License:        MIT
URL:            https://github.com/scikit-hep/iminuit
Source0:        https://files.pythonhosted.org/packages/source/i/iminuit/iminuit-%{version}.tar.gz
%if !%{with test}
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module numpy-devel >= 1.21}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pybind11 >= 2.9.0}
BuildRequires:  %{python_module pybind11-devel}
BuildRequires:  %{python_module scikit-build-core-pyproject >= 0.3.0}
BuildRequires:  cmake >= 3.13
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%endif
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.21
Recommends:     python-matplotlib
Recommends:     python-scipy
%if %{with test}
BuildRequires:  %{python_module iminuit = %{version}}
%if %{with numba}
# numba 0.60 requires numpy < 2.1. This resolves to numpy1,
# if no other **Build**Requires on a conflicting numpy interferes.
BuildRequires:  %{python_module numba}
%endif
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module ipywidgets}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module tabulate}
%endif
# /SECTION
%python_subpackages

%description
iminuit is a Python interface to the MINUIT2 C++ package.

It can be used as a general function minimization method,
but is most commonly used for likelihood fits of models to data,
and to get model parameter error estimates from likelihood profile analysis.

%prep
%setup -q -n iminuit-%{version}
# We use external pybind11, just to be sure remove bundled pybind11 entirely
rm -fr extern/pybind11

%build
%if !%{with test}
export CXXFLAGS="%{optflags}"
export CMAKE_ARGS="-DIMINUIT_EXTERNAL_PYBIND11=ON -DCMAKE_VERBOSE_MAKEFILE=ON"
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%endif

%if %{with test}
%check
%pytest_arch -v
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/iminuit/
%{python_sitearch}/iminuit-%{version}.dist-info/
%endif

%changelog
* Wed Nov 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.30.1:
  * Ci: add 3.13 wheels
  * Fix: root version in docs
  * Allow to modify slider range in interactive widget
  * Fix: add readout_format to slider
  * Show correct ROOT version in documentation
  * Fix odr issue in type_caster which could result in ub when
  - flto is enabled
  * Remove packaging dependency
  * Restore cython tutorial
  * Support sum(w) < 0 in binned fits
  * Set pybind11_findpython on to use findpython cmake mode
  * Fix version parse
  * Improve maintainer metadata
* Mon Sep 23 2024 Ben Greiner <code@bnavigator.de>
- Fix numba/numpy resolve blocker in obs: Test in multibuild
  * -test: no numba, numpy >= 2.1
  * -test-numba: numpy < 2.1 for numba 0.60
  * Remove entry_points empty file workaround: fixed in toolchain
* Fri Aug  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.28.0:
  * drop support for python-3.8 (gh#scikit-hep/iminuit#1015).
  * Fix LeastSquares for functions with more than two arguments
    (gh#scikit-hep/iminuit#1016).
  * Add name argument to all cost functions
    (gh#scikit-hep/iminuit#1017).
- Bump minimum required python-devel to 3.9.
* Fri Mar 15 2024 Ben Greiner <code@bnavigator.de>
- Skip testing with ipywidgets on python39: no longer supported
  since ipython 8.19
- Clean dependencies
- Drop rpmlintrc
* Tue Feb 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.25.2:
  * update to latest root (gh#scikit-hep/iminuit#970).
- Changes from version 2.25.1:
  * improve docs for make_with_signature
    (gh#scikit-hep/iminuit#963).
  * Update benchmark to ROOT-6.30 (gh#scikit-hep/iminuit#967).
  * fix LeastSquares.visualize for models that accept parameter
    array (gh#scikit-hep/iminuit#968).
- Changes from version 2.25.0:
  * Some updates to the Ruff config (gh#scikit-hep/iminuit#933).
  * Add extra config to pytest (gh#scikit-hep/iminuit#932).
  * Cost gradient support (gh#scikit-hep/iminuit#936).
  * Warn on errordef override (gh#scikit-hep/iminuit#937).
  * fix: include debug info on failures
    (gh#scikit-hep/iminuit#946).
  * Benchmark update to ROOT 6.30 (gh#scikit-hep/iminuit#951).
  * Fix use of removed array rules in test
    (gh#scikit-hep/iminuit#952).
  * Fix docstring parsing (gh#scikit-hep/iminuit#953).
  * fix test that requires scipy and raise error on invalid value
    for use_pdf (gh#scikit-hep/iminuit#962).
  * Approximate CDF from PDF (gh#scikit-hep/iminuit#950).
- Do not disable any tests, fixed upstream.
* Thu Sep  7 2023 Markéta Machová <mmachova@suse.com>
- Update to 2.24.0
  * Fix CostSum.visualize bug
  * Fix _safe_log on systems which use 32 bit floats
  * Iteration limit in smart sampling to fix behavior for step functions
  * Clarify meaning of 2d contours in minuit.draw_mnmatrix
  * Support interval type and check compatibility with pydantic
* Fri Jun 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.22.0:
  * add basic latex display support if unicodeit is installed
    [gh#scikit-help/iminuit#858].
  * replace flake8 with ruff [gh#scikit-help/iminuit#859].
  * Integer as variable [gh#scikit-help/iminuit#860].
  * experimental mncontour algorithm [gh#scikit-help/iminuit#861].
  * improve error message for cost function
    [gh#scikit-help/iminuit#863].
  * Add RooFit tutorial [gh#scikit-help/iminuit#867].
  * Use unicodeitplus instead of unicodeit to render LaTeX as
    unicode [gh#scikit-help/iminuit#868].
  * Better ruff settings and adjustments, improvements to README
    [gh#scikit-help/iminuit#871].
  * Update Progressbar [gh#scikit-help/iminuit#872].
  * Add hide_modules and deprecated_parameters
    [gh#scikit-help/iminuit#873].
  * Forward kwargs in Minuit.visualize to plotting function
    [gh#scikit-help/iminuit#874].
  * Ignore missing matplotlib when calling Minuit.repr_html()
    [gh#scikit-help/iminuit#875].
  * Rename keyword nbins to bins in UnbinnedCost.visualize
    [gh#scikit-help/iminuit#876].
  * Roofit tutorials [gh#scikit-help/iminuit#877].
  * better log-spacing detection [gh#scikit-help/iminuit#878].
  * Add LeastSquares.pulls and LeastSquares.prediction
    [gh#scikit-help/iminuit#880].
  * fix-typo-in-basic [gh#scikit-help/iminuit#888].
  * Update fcn.hpp [gh#scikit-help/iminuit#889].
  * Improve docs [gh#scikit-help/iminuit#890].
  * Make covariance fields in display easier to understand
    [gh#scikit-help/iminuit#891].
  * New benchmarks [gh#scikit-help/iminuit#893].
  * Add Minuit.fixto [gh#scikit-help/iminuit#894].
  * fix: make nograd not use grad at all in automatic diff doc
    [gh#scikit-help/iminuit#895].
  * Use scikit-build-core [gh#scikit-help/iminuit#812].
  * Update conclusions after the fix from Jonas
    [gh#scikit-help/iminuit#899].
  * Hide confusing notes in docs: "Not to be initialized by
    users." [gh#scikit-help/iminuit#906].
- Drop missing-headers.patch: Incorporated upstream.
- Add BuildRequires: python-scikit-build-core > 0.3.0.
- Add %%{name}.rpmlintc to suppress a false positive about a
  missing python module (only required for python < 3.9).
* Tue Jun 20 2023 Andreas Schwab <schwab@suse.de>
- missing-headers.patch: add missing headers
- Use the default compiler
- Build with %%{optflags}
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- renenable build for python311 (numba available)
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.21.3:
  * Better docs for limits from annotated model parameters
    (gh#scikit-hep/scikit-hep-testdata#853).
  * Bump pypa/cibuildwheel from 2.12.0 to 2.12.1
    (gh#scikit-hep/scikit-hep-testdata#855).
  * fix template input modification bug in Template class
    (gh#scikit-hep/scikit-hep-testdata#856).
* Fri Mar 24 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.21.2:
  * Fix CITATION.CFF.
- Changes from version 2.21.1:
  * Fix string annotations (gh#scikit-hep/iminuit#849).
  * Specifiy minimum required numpy version
    (gh#scikit-hep/iminuit#848).
- Changes from version 2.21.0:
  * Fix of matrix_format (gh#scikit-hep/iminuit#843).
  * Support annotated model parameters
    (gh#scikit-hep/iminuit#839).
  * Visualize fit in minuit._repr_html_
    (gh#scikit-hep/iminuit#838).
- Disable builds for python 3.11 as python311-numba is missing.
- Use GCC 12 for openSUSE >= 1550 as GCC 13 (now the default)
  causes build failures.
- Update minimum version for (Build)Requires: python-numpy in
  keeping with upstream.
- New BuildRequires: python-typing_extensions (for tests).
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to v2.18.0:
  * Bump actions/checkout from 2 to 3
  * ci: update to Python 3.11 final release
  * move tutorials
  * added visualize function to Minuit
  * Bump pypa/cibuildwheel from 2.10.2 to 2.11.2
  * add more checks for gradients
  * Add Python 3.11, drop 3.6
* Wed Aug 17 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.16.0:
  * Make FixedView act as mask for other views
    [gh#scikit-hep/iminuit#781].
  * Fix typing issues and enable mypy in pre-commit
    [gh#scikit-hep/iminuit#783].
  * Comparison with broadcast [gh#scikit-hep/iminuit#784].
  * Fix corner case treatment of linear constraint
    [gh#scikit-hep/iminuit#785].
  * Root update [gh#scikit-hep/iminuit#786].
- Disable 'test_matrix' test in the check section for 32-bit as
  the test fails for these archs due to a tolerance issue.
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.1:
  * cost.BarlowBeestonLite: method “hpd” has been modified to fix
    performance in cases where bins are not dominated by a single
    template.
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.0:
  * New
  - New cost function cost.BarlowBeestonLite for template fits
    with templates obtained from simulation or sWeighted data
  - Formerly private chi2 utility cost functions
    (cost.poisson_chi2, etc.), are now part of public API
  - Support custom grid in Minuit.profile, iminuit.mncontour,
    iminuit.contour
  - Handle common CL values in Minuit.mnprofile and
    Minuit.mncontour without scipy
  * Fixes
  - Skip tests that use np.float128 on platforms where this type
    is not supported
  - Minuit.valid now returns False if EDM is NaN
  - subtract_min setting is no longer ignored by
    Minuit.draw_contour
  * Documentation: New study about template fits
  * Minuit no longer warns when a function is used that has no
    errordef attribute and Minuit.errordef is not explicitly set.
    The function is assumed to be chi-square-like up to an
    arbitrary constant, unless errordef is explicitly set to
    something else.
  * More type correctness in API, better hiding of private objects
    in library
  * Add option to use external pybind11
- Pass cmake option to build against external pybind11; add
  BuildRequires: python-pybind11 and python-pybind11-devel and
  remove bundled pybind11 from source dir.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.11.2:
  * Fixed wording in cost function tutorial
- Changes from version 2.11.1:
  * Fixed a failure of util.make_with_signature in some
    situations.
  * Raise numpy.VisibleDeprecationWarning instead of
    warnings.DeprecationWarning.
  * util.propagate is deprecated in favour of jacobi.propagate
    from the jacobi library.
- Changes from version 2.11.0:
  * All builtin cost functions now support multidimensional data
  * Matrix.to_dict was added for symmetry with
    BasicValueView.to_dict
  * For long-running fits, total runtime is now shown in FMin
    display and total runtime can be accessed via property
    FMin.time
  * In binned fits when ndof is zero, show reduced chi2 = nan in
    the FMin display instead of raising a ZeroDivisionError
  * Tutorials and studies are now listed separately
  * Tutorial for fits of multivariate data were added
  * The cost function tutorial was improved
  * Studies in regard to performance were added, including a
    comparison with RooFit
* Sat Mar  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.10.0:
  * Minuit.draw_mncontour now works with matplotlib >= 3.5.
  * Builtin cost functions now work correctly when the mask is set
    and data is updated on the existing cost function.
  * Builtin cost functions are now more performant when used with
    weighted binned data.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.9.0:
  * Minuit.draw_mncontour now works with matplotlib >= 3.5.
  * Builtin cost functions now work correctly when the mask is set
    and data is updated on the existing cost function.
  * Builtin cost functions are now more performant when used with
    weighted binned data.
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 2.8.4
  Fixes
  * Pickling of util.Matrix resulted in incomplete state after unpickling,
    which would cause an exception when you tried to print the matrix
  Documentation
  * New tutorial on fitting PDFs that depend on a conditional variable
  * Fixed JAX tutorial, adapting to change in their interface
  * Extended documentation of cost functions
* Thu Sep 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.3:
  * util.propagate now discriminates between diverging derivates
    (using the value NaN for the derivate) and non-converging
    derivatives (using the best value computed so far for the
    derivative).
  * Update documentation.
- Changes from version 2.8.2:
  * Minuit.draw_mncontour can now be used by passing a single
    float to keyword cl, in addition to passing a list of floats.
  * Use pybind11::ssize_t everywhere instead of non-standard
    ssize_t to fix compilation against Python-3.10 on Windows.
  * Update documentation.
* Mon Aug  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.1:
  * Undocumented changes.
* Wed Jul 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.0:
  * Minor API change: Minuit.mncontour now raises RuntimeError
    instead of ValueError if it is not called at a valid minimum
    point.
  * New features: Minuit.mncontour can now be called at any point
    without running a minimiser before, similar to Minuit.minos.
  * Fixes: Minuit.mncontour used to fail if called twice in a row.
* Thu Jun 17 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.1:
  * Calling Minuit.fixed[...] = False on parameter that was not
    fixed before lead to undefined behaviour in Minuit2 C++ code
    (patch submitted to ROOT).
  * Upgrade Minuit2 C++ code to latest ROOT master with simplified
    internal class structure and class tags replaced with enums.
* Wed May  5 2021 Atri Bhattacharya <badshah400@gmai.com>
- Update to version 2.6.0:
  * Builtin cost functions now report the number of data points
    with the attribute Cost.ndata.
  * New attribute Minuit.ndof returns the degrees of freedom if
    the cost function reports it or NaN.
  * New attribute FMin.reduced_chi2 to report the reduced chi2 of
    the fit; returns NaN if the reduced chi2 cannot be computed
    for the cost function, in case of unbinned maximum-likelihood
    or when the attribute Cost.ndata is missing.
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Mon Feb 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.0:
  * New features:
  - iminuit.minimize: Keyword method now accepts "migrad" and
    "simplex".
  - iminuit.minimize: Keyword option now supports keyword "stra"
    to set Minuit.strategy.
  - iminuit.minimize: OptimizeResult.message now states if
    errors are not reliable.
  * Minuit now supports functions wrapped with functools.partial.
  * Upgrade Minuit2 C++ code in ROOT to latest master with
    following improvements:
  - improvement of seed when using an analytical gradient.
  - fix of last minimum state added twice to vector of minimum
    states in some cases (saves a bit of memory).
  * Documentation improvements.
  * Updated tutorial about automatic differentiation, added
    comparison of numba.njit and jax.jit.
- Changes from version 2.3.0:
  * New features: iminuit.cost.BinnedNLL and
    iminuit.cost.ExtendedBinnedNLL now support weighted binned
    data.
  * Bug-fixes: FMin.edm_goal now remains unchanged if Minuit.hesse
    is run after Minuit.migrad.
  * Other: Update to cibuildwheels-1.8.0 and workflow
    simplification.
* Mon Dec 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.1:
  * New features
  - Minuit.profile, Minuit.mnprofile, Minuit.contour,
    Minuit.draw_profile, Minuit.draw_mnprofile, and
    Minuit.draw_contour can now be called with subtract_min=True
    even if Minuit.fmin is None.
  - iminuit.__version__ now also displays the ROOT version of
    the C++ Minuit2 library.
  - Support for adding constant numbers to cost functions, this
    allows you to write sum(cost1, cost2, ...) and may be useful
    to subtract a constant bias from the cost.
  * Other
  - Documentation improvements - Further transition to numpydoc.
  - Clarified that iminuit is based on ROOT code - List full
    iminuit version including ROOT version in docs.
  - Added type hints to many interfaces (incomplete).
  - Renamed iminuit._minuit to iminuit.minuit, making the module
    public.
  - Renamed iminuit._minimize to iminuit.minimize, making the
    module public.
  - pydocstyle added to pre-commit checks.
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.0:
  * New features:
  - Cost functions in iminuit.cost are now additive, creating a
    new cost function with the union of parameters that returns
    the sum of the results of the individual cost functions.
  - iminuit.cost.NormalConstraint was added as a means to add
    soft constraints on a parameter, can also be used to set up
    a covariance matrix between several parameters.
  * Other: Documentation improvements, started transition to numpydoc
- Drop _service file and tests.tar.xz source, since tests are now
  included in the iminuit source tarball.
* Sat Dec 12 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0:
  * Long list of changes, see
    <https://iminuit.readthedocs.io/en/stable/changelog.html#december-7-2020>.
- Add _service file to download tests from github directly as they
  are not included in the pypi tarball any more
  (gh#scikit-hep/iminuit#572).
- New BuildRequires: cmake >= 3.13.
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.4:
    Fixed broken sdist package in 1.5.3
- Changes from version 1.5.3:
  * Fixed a crash when throw_nan=True is used and the throw is
    triggered.
  * Add python_requires (gh#scikit-hep/iminuit#496) by @henryiii.
  * Fixed buggy display of text matrix if npar != 2
    (gh#scikit-hep/iminuit#493).
  * Switch extern Minuit2 repo to official root repo
    (gh#scikit-hep/iminuit#500), ROOT state: a5d880a434.
  * Add ngrad and ngrad_total to FMin display, rename ncalls to
    nfcn_total (gh#scikit-hep/iminuit#489).
  * Use __getattr__ to hide deprecated interface from Python
    help() (gh#scikit-hep/iminuit#491).
  * Improvements to tutorials by @giammi56.
  * Show number of gradient calls in FMin display (if nonzero)
    instead of errordef value.
  * Deprecated:
  - Minuit.ncalls, use Minuit.nfcn instead
  - Minuit.ngrads, use Minuit.ngrad instead
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.2:
  - Fixed regression of the convergence rate of Minuit.migrad for
    low precision cost functions by restoring a heuristic that
    calls Migrad several times if convergence is not reached on
    first try; made this heuristic configurable with iterate
    keyword.
  - Clarify in FMin display how the EDM convergence criterion uses
    the EDM goal.
- Changes from version 1.5.1:
  - Fixed mistake in “parameter at limit” warning, which did not
    report correctly if parameter was at the upper limit.
- Changes from version 1.5.0:
  * New features
  - New more compact function minimum display with warning about
    parameters at limit.
  - Colours adjusted in HTML display to enhance contrast for
    people with color blindness.
  - Allow subclasses to use Minuit.from_array_func
    (gh#scikit-hep/iminuit#467).
  - Nicer tables on terminal thanks to unicode characters.
  - Wrapped functions’ parameters are now recognised by iminuit.
  - Dark theme friendlier HTML style
    (gh#scikit-hep/iminuit#481).
  * Bug-Fixes
  - Fixed reported EDM goal for really small tolerances.
  - Minuit.np_merrors now works correctly when some parameters
    are fixed.
  - Fixed HTML display of Minuit.matrix when some diagonal
    elements are zero.
  * Deprecated
  - Removed nsplit option from Minuit.migrad
    (gh#scikit-hep/iminuit#462).
* Wed Aug  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.9:
  * Fixes an error introduced in 1.4.8 in Minuit.minos when var
    keyword is used and at least one parameter is fixed.
- Changes from versions 1.3.9 through 1.4.8: See
  https://iminuit.readthedocs.io/en/stable/changelog.html.
- Drop python2 builds: no longer supported upstream.
- Drop python-pytestrunner BuildRequires for test in favour of
  python-pytest.
- Fix unresolved status for Leap 15.x on account of multiple
  choices for python3-importlib-metadata
  (python3-importlib-metadata and python3-importlib_metadata).
- Simplify %%check section by dropping directory renaming (no
  longer seems to be needed).
* Wed Nov 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.3.8
  * fixed internal plotting when Minuit.from_array_func is used
  * documentation updates
  * reproduceable build
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Mon Aug 19 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial version.
